;; Generated package description from boxquote.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "boxquote" "2.4.1" "Quote text with a semi-box" '((emacs "28.1")) :commit "6d67daa0d7ac1a1eb0749ddd9a9f221490f2203c" :authors '(("Dave Pearson" . "davep@davep.org")) :maintainer '("Dave Pearson" . "davep@davep.org") :keywords '("convenience" "editing" "quoting") :url "https://github.com/davep/boxquote.el")
